@@ -4,8 +4,8 @@ from time import sleep
 from typing import Any, Callable, Dict, Optional, Tuple, Union
 
 import requests
-from oauthlib.oauth2 import LegacyApplicationClient, TokenExpiredError  # type: ignore
-from requests_oauthlib import OAuth2Session  # type: ignore
+from oauthlib.oauth2 import LegacyApplicationClient, TokenExpiredError
+from requests_oauthlib import OAuth2Session
 
 from pyatmo.exceptions import ApiError
 from pyatmo.helpers import _BASE_URL, ERRORS
@@ -101,7 +101,10 @@ class NetatmoOAuth2:
         return token
 
     def post_request(
-        self, url: str, params: Optional[Dict] = None, timeout: int = 5,
+        self,
+        url: str,
+        params: Optional[Dict] = None,
+        timeout: int = 5,
     ) -> Any:
         """Wrapper for post requests."""
         resp = None
@@ -134,7 +137,9 @@ class NetatmoOAuth2:
                 try:
                     if json_params:
                         rsp = self._oauth.post(
-                            url=url, json=json_params, timeout=timeout
+                            url=url,
+                            json=json_params,
+                            timeout=timeout,
                         )
 
                     else:
@@ -168,15 +173,15 @@ class NetatmoOAuth2:
                     f"{ERRORS.get(resp.status_code, '')} - "
                     f"{resp.json()['error']['message']} "
                     f"({resp.json()['error']['code']}) "
-                    f"when accessing '{url}'"
+                    f"when accessing '{url}'",
                 )
 
-            except JSONDecodeError:
+            except JSONDecodeError as exc:
                 raise ApiError(
                     f"{resp.status_code} - "
                     f"{ERRORS.get(resp.status_code, '')} - "
-                    f"when accessing '{url}'"
-                )
+                    f"when accessing '{url}'",
+                ) from exc
 
         try:
             if "application/json" in resp.headers.get("content-type", []):
@@ -194,7 +199,9 @@ class NetatmoOAuth2:
         return self._oauth.authorization_url(AUTH_URL, state)
 
     def request_token(
-        self, authorization_response: Optional[str] = None, code: Optional[str] = None
+        self,
+        authorization_response: Optional[str] = None,
+        code: Optional[str] = None,
     ) -> Dict[str, str]:
         """
         Generic method for fetching a Netatmo access token.
@@ -252,16 +259,16 @@ class ClientAuth(NetatmoOAuth2):
         password: str,
         scope="read_station",
     ):
-        # pylint: disable=super-init-not-called
-        self._client_id = client_id
-        self._client_secret = client_secret
+        super().__init__(client_id=client_id, client_secret=client_secret, scope=scope)
 
-        self._oauth = OAuth2Session(client=LegacyApplicationClient(client_id=client_id))
+        self._oauth = OAuth2Session(
+            client=LegacyApplicationClient(client_id=self.client_id),
+        )
         self._oauth.fetch_token(
             token_url=AUTH_REQ,
             username=username,
             password=password,
-            client_id=client_id,
-            client_secret=client_secret,
-            scope=scope,
+            client_id=self.client_id,
+            client_secret=self.client_secret,
+            scope=self.scope,
         )
