@@ -34,9 +34,11 @@ class WeatherStationData:
 
         try:
             self.raw_data = fix_id(resp["body"].get("devices"))
-        except KeyError:
+        except KeyError as exc:
             LOG.debug("No <body> in response %s", resp)
-            raise NoDevice("No weather station data returned by Netatmo server")
+            raise NoDevice(
+                "No weather station data returned by Netatmo server",
+            ) from exc
 
         if not self.raw_data:
             raise NoDevice("No weather station available")
@@ -45,17 +47,16 @@ class WeatherStationData:
         self.modules = {}
 
         for item in self.raw_data:
+            # The station name is sometimes not contained in the backend data
+            if "station_name" not in item:
+                item["station_name"] = item.get("home_name", item["type"])
 
             if "modules" not in item:
                 item["modules"] = [item]
 
             for module in item["modules"]:
-                if "module_name" not in module:
-                    if module["type"] == "NHC":
-                        module["module_name"] = module["station_name"]
-
-                    else:
-                        continue
+                if "module_name" not in module and module["type"] == "NHC":
+                    module["module_name"] = module["station_name"]
 
                 self.modules[module["_id"]] = module
                 self.modules[module["_id"]]["main_device"] = item["_id"]
@@ -84,15 +85,17 @@ class WeatherStationData:
 
         res = {}
         for station in [self.stations[station_data["_id"]]]:
+            station_type = station.get("type")
+            station_name = station.get("station_name", station_type)
             res[station["_id"]] = {
-                "station_name": station["station_name"],
-                "module_name": station.get("module_name", station.get("type")),
+                "station_name": station_name,
+                "module_name": station.get("module_name", station_type),
                 "id": station["_id"],
             }
 
             for module in station["modules"]:
                 res[module["_id"]] = {
-                    "station_name": module.get("station_name", station["station_name"]),
+                    "station_name": module.get("station_name", station_name),
                     "module_name": module.get("module_name", module.get("type")),
                     "id": module["_id"],
                 }
@@ -121,7 +124,7 @@ class WeatherStationData:
             if condition == "Wind":
                 # the Wind meter actually exposes the following conditions
                 conditions.extend(
-                    ["WindAngle", "WindStrength", "GustAngle", "GustStrength"]
+                    ["WindAngle", "WindStrength", "GustAngle", "GustStrength"],
                 )
 
             elif condition == "Rain":
@@ -138,8 +141,11 @@ class WeatherStationData:
             # assume all other modules have rf_status, battery_vp, and battery_percent
             conditions.extend(["rf_status", "battery_vp", "battery_percent"])
 
-        if module["type"] in ["NAMain", "NAModule1", "NAModule4", "NHC"]:
-            conditions.extend(["min_temp", "max_temp"])
+        if module["type"] in ["NAMain", "NAModule1", "NAModule4"]:
+            conditions.extend(["temp_trend"])
+
+        if module["type"] == "NAMain":
+            conditions.extend(["pressure_trend"])
 
         if module["type"] in [
             "NAMain",
@@ -201,22 +207,16 @@ class WeatherStationData:
     def check_not_updated(self, station_id: str, delay: int = 3600) -> List:
         """Check if a given station has not been updated."""
         res = self.get_last_data(station_id)
-        ret = []
-        for key, value in res.items():
-            if time.time() - value["When"] > delay:
-                ret.append(key)
-
-        return ret
+        return [
+            key for key, value in res.items() if time.time() - value["When"] > delay
+        ]
 
     def check_updated(self, station_id: str, delay: int = 3600) -> List:
         """Check if a given station has been updated."""
         res = self.get_last_data(station_id)
-        ret = []
-        for key, value in res.items():
-            if time.time() - value["When"] < delay:
-                ret.append(key)
-
-        return ret
+        return [
+            key for key, value in res.items() if time.time() - value["When"] < delay
+        ]
 
     def get_data(
         self,
@@ -253,7 +253,10 @@ class WeatherStationData:
         return self.auth.post_request(url=_GETMEASURE_REQ, params=post_params)
 
     def get_min_max_t_h(
-        self, station_id: str, module_id: str = None, frame: str = "last24"
+        self,
+        station_id: str,
+        module_id: str = None,
+        frame: str = "last24",
     ) -> Optional[Tuple[float, float, float, float]]:
         """Return minimum and maximum temperature and humidity over the given timeframe.
 
@@ -274,6 +277,9 @@ class WeatherStationData:
         elif frame == "day":
             start, end = today_stamps()
 
+        else:
+            raise ValueError("'frame' value can only be 'last24' or 'day'")
+
         resp = self.get_data(
             device_id=station_id,
             module_id=module_id,
